==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoChaosActionBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IoChaosActionBuilder extends IoChaosActionFluentImpl<IoChaosActionBuilder> implements VisitableBuilder<IoChaosAction,IoChaosActionBuilder> {

    IoChaosActionFluent<?> fluent;
    Boolean validationEnabled;

    public IoChaosActionBuilder() {
        this(true);
    }

    public IoChaosActionBuilder(Boolean validationEnabled) {
        this(new IoChaosAction(), validationEnabled);
    }

    public IoChaosActionBuilder(IoChaosActionFluent<?> fluent) {
        this(fluent, true);
    }

    public IoChaosActionBuilder(IoChaosActionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new IoChaosAction(), validationEnabled);
    }

    public IoChaosActionBuilder(IoChaosActionFluent<?> fluent,IoChaosAction instance) {
        this(fluent, instance, true);
    }

    public IoChaosActionBuilder(IoChaosActionFluent<?> fluent,IoChaosAction instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAtime(instance.getAtime()); 
        fluent.withBlocks(instance.getBlocks()); 
        fluent.withCtime(instance.getCtime()); 
        fluent.withFaults(instance.getFaults()); 
        fluent.withGid(instance.getGid()); 
        fluent.withIno(instance.getIno()); 
        fluent.withKind(instance.getKind()); 
        fluent.withLatency(instance.getLatency()); 
        fluent.withMethods(instance.getMethods()); 
        fluent.withMtime(instance.getMtime()); 
        fluent.withNlink(instance.getNlink()); 
        fluent.withPath(instance.getPath()); 
        fluent.withPercent(instance.getPercent()); 
        fluent.withPerm(instance.getPerm()); 
        fluent.withRdev(instance.getRdev()); 
        fluent.withSize(instance.getSize()); 
        fluent.withSource(instance.getSource()); 
        fluent.withType(instance.getType()); 
        fluent.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public IoChaosActionBuilder(IoChaosAction instance) {
        this(instance,true);
    }

    public IoChaosActionBuilder(IoChaosAction instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAtime(instance.getAtime()); 
        this.withBlocks(instance.getBlocks()); 
        this.withCtime(instance.getCtime()); 
        this.withFaults(instance.getFaults()); 
        this.withGid(instance.getGid()); 
        this.withIno(instance.getIno()); 
        this.withKind(instance.getKind()); 
        this.withLatency(instance.getLatency()); 
        this.withMethods(instance.getMethods()); 
        this.withMtime(instance.getMtime()); 
        this.withNlink(instance.getNlink()); 
        this.withPath(instance.getPath()); 
        this.withPercent(instance.getPercent()); 
        this.withPerm(instance.getPerm()); 
        this.withRdev(instance.getRdev()); 
        this.withSize(instance.getSize()); 
        this.withSource(instance.getSource()); 
        this.withType(instance.getType()); 
        this.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableIoChaosAction build() {
        EditableIoChaosAction buildable = new EditableIoChaosAction(fluent.getAtime(),fluent.getBlocks(),fluent.getCtime(),fluent.getFaults(),fluent.getGid(),fluent.getIno(),fluent.getKind(),fluent.getLatency(),fluent.getMethods(),fluent.getMtime(),fluent.getNlink(),fluent.getPath(),fluent.getPercent(),fluent.getPerm(),fluent.getRdev(),fluent.getSize(),fluent.getSource(),fluent.getType(),fluent.getUid());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IoChaosActionBuilder that = (IoChaosActionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoChaosActionBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IoChaosActionBuilder extends IoChaosActionFluentImpl<IoChaosActionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<IoChaosAction,IoChaosActionBuilder> {

    IoChaosActionFluent<?> fluent;
    Boolean validationEnabled;

    public IoChaosActionBuilder() {
        this(true);
    }

    public IoChaosActionBuilder(Boolean validationEnabled) {
        this(new IoChaosAction(), validationEnabled);
    }

    public IoChaosActionBuilder(IoChaosActionFluent<?> fluent) {
        this(fluent, true);
    }

    public IoChaosActionBuilder(IoChaosActionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new IoChaosAction(), validationEnabled);
    }

    public IoChaosActionBuilder(IoChaosActionFluent<?> fluent,IoChaosAction instance) {
        this(fluent, instance, true);
    }

    public IoChaosActionBuilder(IoChaosActionFluent<?> fluent,IoChaosAction instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAtime(instance.getAtime()); 
        fluent.withBlocks(instance.getBlocks()); 
        fluent.withCtime(instance.getCtime()); 
        fluent.withFaults(instance.getFaults()); 
        fluent.withGid(instance.getGid()); 
        fluent.withIno(instance.getIno()); 
        fluent.withKind(instance.getKind()); 
        fluent.withLatency(instance.getLatency()); 
        fluent.withMethods(instance.getMethods()); 
        fluent.withMtime(instance.getMtime()); 
        fluent.withNlink(instance.getNlink()); 
        fluent.withPath(instance.getPath()); 
        fluent.withPercent(instance.getPercent()); 
        fluent.withPerm(instance.getPerm()); 
        fluent.withRdev(instance.getRdev()); 
        fluent.withSize(instance.getSize()); 
        fluent.withSource(instance.getSource()); 
        fluent.withType(instance.getType()); 
        fluent.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public IoChaosActionBuilder(IoChaosAction instance) {
        this(instance,true);
    }

    public IoChaosActionBuilder(IoChaosAction instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAtime(instance.getAtime()); 
        this.withBlocks(instance.getBlocks()); 
        this.withCtime(instance.getCtime()); 
        this.withFaults(instance.getFaults()); 
        this.withGid(instance.getGid()); 
        this.withIno(instance.getIno()); 
        this.withKind(instance.getKind()); 
        this.withLatency(instance.getLatency()); 
        this.withMethods(instance.getMethods()); 
        this.withMtime(instance.getMtime()); 
        this.withNlink(instance.getNlink()); 
        this.withPath(instance.getPath()); 
        this.withPercent(instance.getPercent()); 
        this.withPerm(instance.getPerm()); 
        this.withRdev(instance.getRdev()); 
        this.withSize(instance.getSize()); 
        this.withSource(instance.getSource()); 
        this.withType(instance.getType()); 
        this.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableIoChaosAction build() {
        EditableIoChaosAction buildable = new EditableIoChaosAction(fluent.getAtime(),fluent.getBlocks(),fluent.getCtime(),fluent.getFaults(),fluent.getGid(),fluent.getIno(),fluent.getKind(),fluent.getLatency(),fluent.getMethods(),fluent.getMtime(),fluent.getNlink(),fluent.getPath(),fluent.getPercent(),fluent.getPerm(),fluent.getRdev(),fluent.getSize(),fluent.getSource(),fluent.getType(),fluent.getUid());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IoChaosActionBuilder that = (IoChaosActionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
